==> helm_2.8.6.orig.tar.xz: helm-2.8.6/README.md <==
<p align="center"><a href="http://www.gnu.org/licenses/gpl-3.0.txt"><img src="https://img.shields.io/badge/license-GPL_3-green.svg" alt="License GPL 3" /></a>
  <a href="https://melpa.org/#/helm"><img alt="MELPA" src="https://melpa.org/packages/helm-badge.svg"/></a>
  <a href="https://stable.melpa.org/#/helm"><img alt="MELPA Stable" src="https://stable.melpa.org/packages/helm-badge.svg"/></a>
</p>


<h1 align="center">Emacs-Helm</h1>

<p align="center">
  <img src="https://avatars3.githubusercontent.com/u/1541688?v=3&amp;s=200" alt="Emacs-helm" title="" />
</p>

***
<p align="justify">
  <b>Helm</b> is an Emacs framework for incremental completions and narrowing
  selections. It provides an easy-to-use API for developers wishing to build
  their own Helm applications in Emacs, powerful search tools and dozens of
  already built-in commands providing completion to almost everything.
  It is a must-have for anyone using Emacs as a main work environment.
  Helm has been widely adopted by many Emacs power-users.
  It is available in Melpa and can be easily installed from the Emacs package manager.
</p>

***
<p align="center">
  <a href="https://emacs-helm.github.io/helm/"><b>Homepage</b></a> |
  <a href="https://github.com/emacs-helm/helm/releases"><b>Downloads</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki#install"><b>Get started</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki"><b>Helm wiki</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki/FAQ"><b>FAQ</b></a>
</p>

***

<p align="center">
  Maintaining Helm requires a <a href="https://github.com/emacs-helm/helm/commits?author=thierryvolpiatto"><b>lot of work</b></a>
  I have done voluntarily since 2011.<br>
  As it demands lots of my time it gets increasingly difficult<br>
  maintaining it without financial help.<br>
  If you think Helm makes your life easier,<br><b>please consider making a donation.</b>
</p>

<p align="center">
  <i>Thank you! &mdash; Thierry Volpiatto</i>
</p>

<div align="center">
  <a href="https://www.paypal.me/thierryvolpiatto/20">
    <img title="Donate with Paypal"
         alt="Donate with Paypal"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/paypal.png?raw=true"></a>
  &nbsp;&nbsp;
  <a href="https://patreon.com/preview/30231724baf440fabe80d44d0ee77067">
    <img title="Donate monthly using Patreon"
         alt="Donate monthly using Patreon"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/patreon-25x.png?raw=true"></a>
  &nbsp;&nbsp;
</div>

***

<p align="center">
  Helm in action searching with <a href="https://github.com/ggreer/the_silver_searcher"<b>Grep Ag</b></a>
                                   </p>

<p align="center">
  <img src="https://github.com/emacs-helm/helm/blob/master/images/helm-grep-ag-persistent.png?raw=true" alt="Emacs-helm grep ag" title="" />
</p>

[badge-license]: https://img.shields.io/badge/license-GPL_3-green.svg

==> helm_2.9.2.orig.tar.xz: helm-2.9.2/README.md <==
<p align="center"><a href="http://www.gnu.org/licenses/gpl-3.0.txt"><img src="https://img.shields.io/badge/license-GPL_3-green.svg" alt="License GPL 3" /></a>
  <a href="https://melpa.org/#/helm"><img alt="MELPA" src="https://melpa.org/packages/helm-badge.svg"/></a>
  <a href="https://stable.melpa.org/#/helm"><img alt="MELPA Stable" src="https://stable.melpa.org/packages/helm-badge.svg"/></a>
</p>


<h1 align="center">Emacs-Helm</h1>

<p align="center">
  <img src="https://avatars3.githubusercontent.com/u/1541688?v=3&amp;s=200" alt="Emacs-helm" title="" />
</p>

***
<p align="justify">
  <b>Helm</b> is an Emacs framework for incremental completions and narrowing
  selections. It provides an easy-to-use API for developers wishing to build
  their own Helm applications in Emacs, powerful search tools and dozens of
  already built-in commands providing completion to almost everything.
  It is a must-have for anyone using Emacs as a main work environment.
  Helm has been widely adopted by many Emacs power-users.
  It is available in Melpa and can be easily installed from the Emacs package manager.
</p>

***
<p align="center">
  <a href="https://emacs-helm.github.io/helm/"><b>Homepage</b></a> |
  <a href="https://github.com/emacs-helm/helm/releases"><b>Downloads</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki#install"><b>Get started</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki"><b>Helm wiki</b></a> |
  <a href="https://github.com/emacs-helm/helm/wiki/FAQ"><b>FAQ</b></a>
</p>

***

<p align="center">
  Maintaining Helm requires a <a href="https://github.com/emacs-helm/helm/commits?author=thierryvolpiatto"><b>lot of work</b></a>,
  which I have done voluntarily since 2011.<br>
  As it demands lots of my time it gets increasingly difficult<br>
  maintaining it without financial help.<br>
  Thanks to all the people that are helping or have helped Helm development,<br>
  but they are actually too few to continue serenely.<br>
  By the way, after the release of version 3.0 I will have to stop<br>
  developing Helm seriously until I get enough support,<br> 
  only providing a minimal bugfix maintenance.<br>
  Thanks for your understanding<br>
</p>

<p align="center">
  <i>Thank you! &mdash; Thierry Volpiatto</i>
</p>

<div align="center">
  <a href="https://www.paypal.me/thierryvolpiatto/20">
    <img title="Donate with Paypal"
         alt="Donate with Paypal"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/paypal.png?raw=true"></a>
  &nbsp;&nbsp;
  <a href="https://patreon.com/preview/30231724baf440fabe80d44d0ee77067">
    <img title="Donate monthly using Patreon"
         alt="Donate monthly using Patreon"
         style="height: 50px; width: auto;"
         src="https://github.com/emacs-helm/helm/blob/master/images/patreon-25x.png?raw=true"></a>
  &nbsp;&nbsp;
</div>

***

<p align="center">
  Helm in action searching with <a href="https://github.com/ggreer/the_silver_searcher"<b>Grep Ag</b></a>
                                   </p>

<p align="center">
  <img src="https://github.com/emacs-helm/helm/blob/master/images/helm-grep-ag-persistent.png?raw=true" alt="Emacs-helm grep ag" title="" />
</p>

[badge-license]: https://img.shields.io/badge/license-GPL_3-green.svg
